@@ -37,13 +37,14 @@ class MCP23008(MCP230XX):
     at the specified I2C address.
     """
 
-    def __init__(self, i2c, address=_MCP23008_ADDRESS):
+    def __init__(self, i2c, address=_MCP23008_ADDRESS, reset=True):
         super().__init__(i2c, address)
 
-        # Reset to all inputs with no pull-ups and no inverted polarity.
-        self.iodir = 0xFF
-        self.gppu = 0x00
-        self._write_u8(_MCP23008_IPOL, 0x00)
+        if reset:
+            # Reset to all inputs with no pull-ups and no inverted polarity.
+            self.iodir = 0xFF
+            self.gppu = 0x00
+            self._write_u8(_MCP23008_IPOL, 0x00)
 
     @property
     def gpio(self):
