@@ -3,6 +3,8 @@
 #
 # SPDX-License-Identifier: MIT
 
+# pylint: disable=too-many-public-methods
+
 """
 `mcp23017`
 ====================================================
@@ -23,6 +25,7 @@ _MCP23017_ADDRESS = const(0x20)
 _MCP23017_IODIRA = const(0x00)
 _MCP23017_IODIRB = const(0x01)
 _MCP23017_IPOLA = const(0x02)
+_MCP23017_IPOLB = const(0x03)
 _MCP23017_GPINTENA = const(0x04)
 _MCP23017_DEFVALA = const(0x06)
 _MCP23017_INTCONA = const(0x08)
@@ -42,13 +45,14 @@ class MCP23017(MCP230XX):
     at the specified I2C address.
     """
 
-    def __init__(self, i2c, address=_MCP23017_ADDRESS):
+    def __init__(self, i2c, address=_MCP23017_ADDRESS, reset=True):
         super().__init__(i2c, address)
-        # Reset to all inputs with no pull-ups and no inverted polarity.
-        self.iodir = 0xFFFF
-        self.gppu = 0x0000
-        self.iocon = 0x4  # turn on IRQ Pins as open drain
-        self._write_u16le(_MCP23017_IPOLA, 0x0000)
+        if reset:
+            # Reset to all inputs with no pull-ups and no inverted polarity.
+            self.iodir = 0xFFFF
+            self.gppu = 0x0000
+            self.iocon = 0x4  # turn on IRQ Pins as open drain
+            self._write_u16le(_MCP23017_IPOLA, 0x0000)
 
     @property
     def gpio(self):
@@ -162,6 +166,42 @@ class MCP23017(MCP230XX):
         assert 0 <= pin <= 15
         return DigitalInOut(pin, self)
 
+    @property
+    def ipol(self):
+        """The raw IPOL output register.  Each bit represents the
+        polarity value of the associated pin (0 = normal, 1 = inverted), assuming that
+        pin has been configured as an input previously.
+        """
+        return self._read_u16le(_MCP23017_IPOLA)
+
+    @ipol.setter
+    def ipol(self, val):
+        self._write_u16le(_MCP23017_IPOLA, val)
+
+    @property
+    def ipola(self):
+        """The raw IPOL A output register.  Each bit represents the
+        polarity value of the associated pin (0 = normal, 1 = inverted), assuming that
+        pin has been configured as an input previously.
+        """
+        return self._read_u8(_MCP23017_IPOLA)
+
+    @ipola.setter
+    def ipola(self, val):
+        self._write_u8(_MCP23017_IPOLA, val)
+
+    @property
+    def ipolb(self):
+        """The raw IPOL B output register.  Each bit represents the
+        polarity value of the associated pin (0 = normal, 1 = inverted), assuming that
+        pin has been configured as an input previously.
+        """
+        return self._read_u8(_MCP23017_IPOLB)
+
+    @ipolb.setter
+    def ipolb(self, val):
+        self._write_u8(_MCP23017_IPOLB, val)
+
     @property
     def interrupt_configuration(self):
         """The raw INTCON interrupt control register. The INTCON register
